summaryrefslogtreecommitdiff
path: root/sw/source/uibase/wrtsh
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2016-04-22 10:08:07 +0200
committerStephan Bergmann <sbergman@redhat.com>2016-04-22 10:08:07 +0200
commit85825e0fd54551735ef05b8484f71974734b9135 (patch)
tree8bece458e55c1b5eab7559076579bf76cca8df68 /sw/source/uibase/wrtsh
parentfc233b52ce2acc1bcd7cecc3d51bcab870c81932 (diff)
Avoid reserved identifiers
Change-Id: I27ff0f4f0eb395d7e0a60dd604758c220a3134c4
Diffstat (limited to 'sw/source/uibase/wrtsh')
-rw-r--r--sw/source/uibase/wrtsh/delete.cxx16
-rw-r--r--sw/source/uibase/wrtsh/move.cxx4
-rw-r--r--sw/source/uibase/wrtsh/wrtsh4.cxx24
3 files changed, 22 insertions, 22 deletions
diff --git a/sw/source/uibase/wrtsh/delete.cxx b/sw/source/uibase/wrtsh/delete.cxx
index 3375cbb2f33f..8ce3d4222ff2 100644
--- a/sw/source/uibase/wrtsh/delete.cxx
+++ b/sw/source/uibase/wrtsh/delete.cxx
@@ -431,7 +431,7 @@ void SwWrtShell::DelToStartOfSentence()
if(IsStartOfDoc())
return;
OpenMark();
- long nRet = _BwdSentence() ? Delete() : 0;
+ long nRet = BwdSentence_() ? Delete() : 0;
CloseMark( 0 != nRet );
}
@@ -463,7 +463,7 @@ long SwWrtShell::DelToEndOfSentence()
}
else
{
- nRet = _FwdSentence() ? Delete() : 0;
+ nRet = FwdSentence_() ? Delete() : 0;
}
CloseMark( 0 != nRet );
return nRet;
@@ -478,11 +478,11 @@ void SwWrtShell::DelNxtWord()
EnterStdMode();
SetMark();
if(IsEndWrd() && !IsStartWord())
- _NxtWrdForDelete(); // #i92468#
+ NxtWrdForDelete(); // #i92468#
if(IsStartWord() || IsEndPara())
- _NxtWrdForDelete(); // #i92468#
+ NxtWrdForDelete(); // #i92468#
else
- _EndWrd();
+ EndWrd();
long nRet = Delete();
if( nRet )
@@ -501,12 +501,12 @@ void SwWrtShell::DelPrvWord()
EnterStdMode();
SetMark();
if ( !IsStartWord() ||
- !_PrvWrdForDelete() ) // #i92468#
+ !PrvWrdForDelete() ) // #i92468#
{
if (IsEndWrd() || IsSttPara())
- _PrvWrdForDelete(); // #i92468#
+ PrvWrdForDelete(); // #i92468#
else
- _SttWrd();
+ SttWrd();
}
long nRet = Delete();
if( nRet )
diff --git a/sw/source/uibase/wrtsh/move.cxx b/sw/source/uibase/wrtsh/move.cxx
index 02cbb152fc2a..81b9c7a2d400 100644
--- a/sw/source/uibase/wrtsh/move.cxx
+++ b/sw/source/uibase/wrtsh/move.cxx
@@ -499,7 +499,7 @@ bool SwWrtShell::PopCursor(bool bUpdate, bool bSelect)
// positions are thrown away.
else
{
- _ResetCursorStack();
+ ResetCursorStack_();
return false;
}
}
@@ -517,7 +517,7 @@ bool SwWrtShell::PopCursor(bool bUpdate, bool bSelect)
// Reset of all pushed cursor positions; these will
// not be displayed ( --> No Start-/EndAction!!)
-void SwWrtShell::_ResetCursorStack()
+void SwWrtShell::ResetCursorStack_()
{
while(m_pCursorStack)
{
diff --git a/sw/source/uibase/wrtsh/wrtsh4.cxx b/sw/source/uibase/wrtsh/wrtsh4.cxx
index 60db3754d6a2..4b4d4783d53a 100644
--- a/sw/source/uibase/wrtsh/wrtsh4.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh4.cxx
@@ -27,7 +27,7 @@
// non-sentence separators on sentence separator.
// The begin of paragraph is also the word beginning.
-bool SwWrtShell::_SttWrd()
+bool SwWrtShell::SttWrd()
{
if ( IsSttPara() )
return true;
@@ -48,7 +48,7 @@ bool SwWrtShell::_SttWrd()
// punctuation marks.
// The end of a paragraph is also the end of a word.
-bool SwWrtShell::_EndWrd()
+bool SwWrtShell::EndWrd()
{
if ( IsEndWrd() )
return true;
@@ -64,7 +64,7 @@ bool SwWrtShell::_EndWrd()
return true;
}
-bool SwWrtShell::_NxtWrd()
+bool SwWrtShell::NxtWrd_()
{
bool bRet = false;
while( IsEndPara() ) // If already at the end, then the next???
@@ -95,7 +95,7 @@ bool SwWrtShell::_NxtWrd()
return bRet;
}
-bool SwWrtShell::_PrvWrd()
+bool SwWrtShell::PrvWrd_()
{
bool bRet = false;
while( IsSttPara() )
@@ -127,8 +127,8 @@ bool SwWrtShell::_PrvWrd()
}
// #i92468#
-// method code of <SwWrtShell::_NxtWrd()> before fix for issue i72162
-bool SwWrtShell::_NxtWrdForDelete()
+// method code of <SwWrtShell::NxtWrd_()> before fix for issue i72162
+bool SwWrtShell::NxtWrdForDelete()
{
if ( IsEndPara() )
{
@@ -150,8 +150,8 @@ bool SwWrtShell::_NxtWrdForDelete()
return true;
}
-// method code of <SwWrtShell::_PrvWrd()> before fix for issue i72162
-bool SwWrtShell::_PrvWrdForDelete()
+// method code of <SwWrtShell::PrvWrd_()> before fix for issue i72162
+bool SwWrtShell::PrvWrdForDelete()
{
if ( IsSttPara() )
{
@@ -173,7 +173,7 @@ bool SwWrtShell::_PrvWrdForDelete()
return true;
}
-bool SwWrtShell::_FwdSentence()
+bool SwWrtShell::FwdSentence_()
{
Push();
ClearMark();
@@ -190,7 +190,7 @@ bool SwWrtShell::_FwdSentence()
return true;
}
-bool SwWrtShell::_BwdSentence()
+bool SwWrtShell::BwdSentence_()
{
Push();
ClearMark();
@@ -207,7 +207,7 @@ bool SwWrtShell::_BwdSentence()
return true;
}
-bool SwWrtShell::_FwdPara()
+bool SwWrtShell::FwdPara_()
{
Push();
ClearMark();
@@ -218,7 +218,7 @@ bool SwWrtShell::_FwdPara()
return bRet;
}
-bool SwWrtShell::_BwdPara()
+bool SwWrtShell::BwdPara_()
{
Push();
ClearMark();